#
# spec file for package python-tenacity
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-tenacity
Version:        9.0.0
Release:        1.2
Summary:        Python module for retrying code until it succeeeds
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/jd/tenacity
Source:         https://files.pythonhosted.org/packages/source/t/tenacity/tenacity-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tornado6 >= 6.4.1}
BuildRequires:  %{python_module typeguard}
BuildRequires:  %{python_module typing-extensions}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-tornado6
BuildArch:      noarch
%python_subpackages

%description
Tenacity is a general-purpose retrying library, written in Python, to simplify
the task of adding retry behavior to just about anything.
It originates from a fork of `Retrying`_
Features
--------
- Generic Decorator API
- Specify stop condition (i.e. limit by number of attempts)
- Specify wait condition (i.e. exponential backoff sleeping between attempts)
- Customize retrying on Exceptions
- Customize retrying on expected returned result

%prep
%setup -q -n tenacity-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest --ignore tenacity/tests/test_asyncio.py -k 'not test_retry_type_annotations'

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/tenacity
%{python_sitelib}/tenacity-%{version}.dist-info

%changelog
* Sun Sep  8 2024 Dirk Müller <dmueller@suse.com>
- update to 9.0.0:
  * Respects `min` argument for `wait_random_exponential`
  * Bump major version to warn API breakage on statistics
    attribute
- update to 8.5.0:
  * fix: Restore contents of retry attribute for wrapped
    functions
* Thu Sep  5 2024 Markéta Machová <mmachova@suse.com>
- Fix build on Leap 15.6
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 8.4.2:
  * fix: Avoid overwriting local contexts with retry decorator
* Wed Jun 19 2024 Dirk Müller <dmueller@suse.com>
- update to 8.4.1:
  * Include `tenacity.asyncio` subpackage in release dist
- update to 8.4.0:
  * Add async strategies
  * Support Trio out-of-the-box
* Mon Jun 10 2024 Dirk Müller <dmueller@suse.com>
- update to 8.3.0:
  * Added a new stop function: `stop_before_delay`, which will
    stop execution if the next sleep time would cause overall
    delay to exceed the specified delay. Useful for use cases
    where you have some upper bound on retry times that you must
    not exceed, so returning before that timeout is preferable
    than returning after that timeout.
  * Preserve __defaults__ and __kwdefaults__ through retry
    decorator
- use PEP517 build
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 3.2.3:
  * remove support for python 3.6
  * Fix tests for typeguard 3.x
  * Add support for async sleep functions in tenacity.retry
    annotation
* Wed May 31 2023 Dirk Müller <dmueller@suse.com>
- update to 8.2.2:
  * feat: accept datetime.timedelta instances as argument to `stop_after..
  * fix: docstring for wait_exponential_jitter
  * fix: remove __iter__ from AsyncRetring
  * Add retry_if_exception_cause_type and wait_exponential_jitter
  * better wait.WaitBaseT annotation
  * CI conversion to GitHub actions
* Mon May 15 2023 Johannes Kastl <kastl@b1-systems.de>
- disable check 'test_retry_type_annotations' that fails due to
  `TypeError: check_type() takes 2 positional arguments but 3 were
  given`
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Fri Nov 11 2022 pgajdos@suse.com
- silent rpmlint
* Fri Nov 11 2022 pgajdos@suse.com
- python-six is not required
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 8.1.0 (included changes also from 8.0.1, 8.0.0, 7.0.0)
  * feat: Add retry_if_exception_cause_type (#362)
  * Support `datetime.timedelta` as a valid wait unit type (#342)
  * Show All Exception Predicates in Docs (#332)
  * Implement a wait.wait_exponential_jitter per Google's storage guide (#351)
  * Define a ClientError to fix Sphinx build errors (#352)
  * Merge pull request #340 from jd/fix-mergify
  * ci: fix Mergify config
  * Merge pull request #337 from william-silversmith/master
  * docs: show how to use retry_if_not_exception_type
  * Rickroll a function name in one of the examples (#331)
  * Fix after_log logger format (#317)
  * Drop `py2` tag from the wheel name (#320)
  * Add a __repr__ method to RetryCallState objects (#302)
  * Add type annotations to cover all code. (#315)
  * Fix #307 : Drop deprecated APIs (#314)
  * Fix DeprecationWarnings in tests (#313)
  * Do not package tests with tenacity (#308)
  * Fix issue #288 : __name__ and other attributes for async functions (#312)
  * Use f-strings instead of `str.format` as faster and easier to read (#311)
  * Replace abc.ABCMeta with abc.ABC (#310)
  * Remove encoding declarations (#309)
  * Merge pull request #306 from penguinolog/black_full_ci
  * Use black instead of "flake8-black" on CI.
  * Fix #291: drop python < 3.6 (#304)
  * Merge pull request #293 from and-semakin/drop_deprecated_pythons
  * Drop support for deprecated Python versions (2.7 and 3.5)
  * Add retry_if_not_exception_type() (#300)
  * Make logger more compatible (#294)
  * ci: fix pep8 error (#297)
  * Merge pull request #286 from jd/reno-mergify
  * Add Python 3.8 in tox.ini
  * Fix upload job
  * Merge pull request #202 from jd/release-auto
  * Release via CircleCI
  * Merge pull request #191 from bersace/context-manager
  * Merge branch 'master' into context-manager
  * Merge pull request #201 from bersace/async
  * Ensure coroutine passes asyncio.iscoroutinefunction
  * Test async keyword
  * Retry code block with context manager
  * Merge pull request #200 from Dectinc/master
  * Fix setup.cfg typo
  * Merge pull request #198 from BATS/py2-compatability-for-_asyncio-module
  * Ensure that the _asyncio.py module can be compiled, even on Python 2
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 8.0.1
  * no upstream changelog
* Thu Apr 22 2021 Dirk Müller <dmueller@suse.com>
- update to 6.3.1:
  * Make AsyncRetrying callable
  * Replace nap.sleep with a method to allow mocking after import
  * Always return booleans from all retry_* methods
  * Fix asyncio.iscoroutinefunction(f) check for decorated function
  * Add call method to AsyncRetying
* Tue Jun 30 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 6.2.0:
  * before_sleep_log: Add an exc_info option to include exception tracebacks
  * docs: fix duplicate function names (#226)
  * AsyncRetrying can use an async iterator (#222)
  * Add minimal type definitions for @retry decorator (#221)
- Add typguard to BuildRequires
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Fri Feb 28 2020 Dirk Mueller <dmueller@suse.com>
- update to 6.1.0:
  * further Python 3.8 fixes
* Fri Dec 20 2019 Dirk Mueller <dmueller@suse.com>
- update to 6.0.0
  * Python 3.8 enablement
* Wed Aug 28 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 5.1.1
  * upstream switched to reno, so no upstream changelog
  * Use setuptools_scm for packaging
  * Drop Python 3.4
  * Reduce wait_exponential power by 1 so first wait is equal to multiplier
* Thu Apr 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 5.0.4
  * Try using unshallow clone
  * Add support for Python 3.7
  * Add test for attempt numbers in interleaved async coroutines
  * Fix wait_chain to be runnable multiple times
  * Fix six.wraps having a problem with __name__ attr on Py2
  * Add retry_if_exception_message and complement
  * RetryCallState: add retry_object & next_action fields
  * Tweak wait funcs to accept call_state with backward compat
  * Add RetryCallState class
  * Documentation fixes
* Wed Jan  9 2019 Jonathan Brownell <jbrownell@suse.com>
- Use "Requires:" instead of "Recommends:" on older build platforms
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Oct 18 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Thu Oct 11 2018 Dirk Mueller <dmueller@suse.com>
- update to 4.12.0:
  * add retry\_error\_callback param
  * Fix Mergify conf
  * Enable mergify
  * Implement before\_sleep logging hook
  * Rename tenacity.async to tenacity.\_asyncio
  * Remove useless install of nose
  * Switch to pytest
  * Fix codeblock formatting
  * Document how to use Trio/curio
  * Catch BaseException rather than just Exception
  * Fix pep8 errors
  * Only install monotonic on Python 2
  * Stop using pbr to build documentation
  * Add \`license\` key to \`setup.cfg\`
  * Avoid inspect.getargspec deprecation warning
  * Don't fall over if an old version of tornado is installed
  * Allow to specify RetryError
* Wed Jan 10 2018 jengelh@inai.de
- Remove repetition of license terms in description.
* Wed Jan 10 2018 toddrme2178@gmail.com
- update to 4.8.0
  * Allow waiters to introspect last result
- update to 4.7.1
  * Missed top level import of stop\_when\_event\_set
  * Mention Tornado minimum version in README
  * Fix unless\_exception test names and add no input test
- update to 4.7.0
  * Add Tornado support
  * Fix pep8
- update to 4.6.1
  * Simplify wrapping code
- update to 4.6.0
  * Implement \`retry\_with' on decorated functions
- Implement single-spec version
* Thu Nov  2 2017 dmueller@suse.com
- update to 4.5.0:
  * Replace hacking with flake8 extensions
  * Fix import order
  * Put a default sleep attribute on BaseRetrying
  * async: allow to specify a different sleep method
  * Issue-8: Make sure doc examples run (#89)
  * Remove Python 3.4 support
* Tue Aug 22 2017 tbechtold@suse.com
- update to 4.4.0:
  * Document wait\_random\_exponential strategy
  * Rename wait\_full\_jitter to wait\_random\_exponential
  * Add retry\_unless\_exception\_type
  * Add missing ')' to README.rst
  * Do not duplicate statistics fields in instance
  * Do not start trial\_start\_time as an attribute
  * Add an example on how to combine stop conditions
  * Put a link to the GitHub issue of retrying about the fork
  * feat: added wait\_full\_jitter
  * Add new event based sleep and stop
  * Add \`wraps' method directly on Retrying object
  * wait: handle OverflowError
  * doc: raise Exception in example so they actually work
  * Remove weird example with retry\_if\_io\_error
  * Bump version for new feature
  * Add Python 3.6 support
  * Add retry\_if\_not\_result class to compliment the existing retry\_if\_result class
  * Fix six minimum version
  * doc: rewrite the before explanation
  * Add \_\_call\_\_ on BaseRetrying class
  * Document before and after keywords
  * Remove useless MANIFEST
  * Remove non-working PyPI download image
  * Bump hacking to 0.13
  * Use Python 3 for pep8 tox target
  * Remove deprecated wait\_jitter
* Fri Feb 10 2017 tbechtold@suse.com
- update to 3.7.1:
  * Fix pep8 errors
  * Correctly set the exception if we TryAgain for ever
* Sun Dec 18 2016 dmueller@suse.com
- update to 3.6.0:
  * Retry on coroutines
  * Run flake8 only with latest python
  * Deduplicate retry decorator logic
  * Extract controller IOs in subclass
  * Allow to combine stop conditions
  * Add SayThanks
  * retry: implement bitwise operators on retry strategies
  * retry: add retry_all
* Fri Dec  2 2016 dmueller@suse.com
- update to 3.4.0:
  * Deprecate wait_jitter for wait_random
  * Align tox and travis settings
  * Fix README typo
  * Bump hacking to 0.12
  * Fix README.rst wrong description
  * This is using floating point seconds (not milliseconds)
  * Some small docstring updates
  * Use py3.x compat print in README.rst
  * Fix typo in retry_if_exception example
* Wed Nov  9 2016 dmueller@suse.com
- update to 3.3.0:
  * Implement '+' operator for wait strategies
  * Rename `_retrying` attribute to `retry` and document it
  * Store retrying object as an attribute of retried function
  * Make sure statistics are thread locals
* Mon Sep 26 2016 tbechtold@suse.com
- Initial packaging (version 3.1.1)
